@@ -51,7 +51,6 @@ class Config(object):
         :returns: list of elements
 
         """
-        print self._tree, name
         qstr = ".//%s" % (name)
         return self._tree.findall(qstr)
 
@@ -254,14 +253,15 @@ class Field(Config):
 
         self.label = entity.attrib.get('label', self.name.capitalize())
         """Label of the field. If no label is provied the a capitalized
-        form of the name is used"""
+        form of the name is used. To not render a label at all define a
+        label with an empty string."""
 
         self.number = entity.attrib.get('number', '')
         """A ordering number for the field. In some form it is helpfull
         to be able to refer to a specific field by its number. The
         number will be rendered next to the label of the field."""
 
-        self.type = entity.attrib.get('type', 'string')
+        self.type = entity.attrib.get('type')
         """The datatype for this field. The data type is important for
         converting the submitted data into a python value. Note that
         this option is ignored if the form is used to render an
@@ -319,14 +319,6 @@ class Field(Config):
             expr = parser.parse(expr)
             self.rules.append(Rule(expr, msg, mode))
 
-        # Finally add a required rule if the field is marked as
-        # requiered.
-        if self.required:
-            expr = "bool($%s)" % self.name
-            msg = "This field is required. You need to provide a value"
-            mode = "pre"
-            expr = parser.parse(expr)
-            self.rules.append(Rule(expr, msg, mode))
 
 class Renderer(Config):
     """Configuration class for FieldRenderers. This class gives an
@@ -344,3 +336,5 @@ class Renderer(Config):
         - Datepicker
         - Textarea
         """
+    def __getattr__(self, name):
+        return self._tree.attrib.get(name)
